<?php
/**
 * indie functions and definitions
 *
 * @package indie
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 940; /* pixels */
}

if ( ! function_exists( 'indie_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function indie_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on indie, use a find and replace
	 * to change 'indie' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'indie', get_template_directory() . '/languages' );

	// Feed Links
	add_theme_support( 'automatic-feed-links' );
	
	// Post formats
	add_theme_support( 'post-formats', array( 'gallery', 'quote' ) );

	// Post thumbnails
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'full-thumb', 940, 0, true );
	add_image_size( 'slider-thumb', 650, 440, true );
	add_image_size( 'thumb', 440, 294, true );


	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'indie' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );
	
	
}
endif; // indie_setup
add_action( 'after_setup_theme', 'indie_setup' );

/**
 * Author Social Links
 */
function indie_contactmethods( $contactmethods ) {

	$contactmethods['twitter']   = 'Twitter Username';
	$contactmethods['facebook']  = 'Facebook Username';
	$contactmethods['google']    = 'Google Plus Username';
	$contactmethods['tumblr']    = 'Tumblr Username';
	$contactmethods['instagram'] = 'Instagram Username';
	$contactmethods['pinterest'] = 'Pinterest Username';

	return $contactmethods;
}
add_filter('user_contactmethods','indie_contactmethods',10,1);


/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function indie_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'indie' ),
		'id'            => 'sidebar-1',
        'description'   => __( 'Main sidebar that appears on the left or right.', 'indie' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
    register_sidebar( array(
		'name' => __( 'Footer 1', 'indie' ),
		'id' => 'footer-1',
        'description'   => __( 'One of three widget areas that will apear at the bottom of the site.', 'indie' ),
		'before_widget' => '<aside id="%1$s" class="widget first %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></aside>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	) );
    register_sidebar( array(
		'name' => __( 'Footer 2', 'indie' ),
		'id' => 'footer-2',
        'description'   => __( 'One of three widget areas that will apear at the bottom of the site.', 'indie' ),
		'before_widget' => '<aside id="%1$s" class="widget first %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></aside>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',        
	) );
    register_sidebar( array(
		'name' => __( 'Footer 3', 'indie' ),
		'id' => 'footer-3',
        'description'   => __( 'One of three widget areas that will apear at the bottom of the site.', 'indie' ),
		'before_widget' => '<aside id="%1$s" class="widget first %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></aside>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	) );
}
add_action( 'widgets_init', 'indie_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function indie_scripts() {
	
	wp_register_style('indie-style', get_stylesheet_uri() );
	wp_register_style('owl-css', get_stylesheet_directory_uri() . '/css/owl.carousel.css');
	wp_register_style('owl-theme-css', get_stylesheet_directory_uri() . '/css/owl.theme.css');
	wp_register_style('font-awesome', get_stylesheet_directory_uri() . '/css/font-awesome.min.css');
	wp_register_style('flexslider-css', get_stylesheet_directory_uri() . '/css/flexslider.css');

	wp_register_script('indie-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_register_script('indie-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
	wp_register_script('owl', get_template_directory_uri() . '/js/owl.carousel.min.js', 'jquery', '', true);
	wp_register_script('fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', 'jquery', '', true);
	wp_register_script('tooltipsy', get_template_directory_uri() . '/js/tooltipsy.jquery.js', 'jquery', '', true);
	wp_register_script('flexslider-js', get_template_directory_uri() . '/js/jquery.flexslider-min.js', 'jquery', '', true);
	wp_register_script('inview', get_template_directory_uri() . '/js/inview.min.js', 'jquery', '', true);
	wp_register_script('indie_scripts', get_template_directory_uri() . '/js/indie.js', 'jquery', NULL, true);
	
	wp_enqueue_style('indie-style');
	wp_enqueue_style('owl-css');
	wp_enqueue_style('owl-theme-css');
	wp_enqueue_style('font-awesome');
	wp_enqueue_style('flexslider-css');
	
	wp_enqueue_script('jquery');
	wp_enqueue_script('inview');
	wp_enqueue_script('flexslider-js');
	wp_enqueue_script('fitvids');
	wp_enqueue_script('indie-navigation');
	wp_enqueue_script('indie-skip-link-focus-fix');
	wp_enqueue_script('owl');
	wp_enqueue_script('tooltipsy');
	wp_enqueue_script('indie_scripts');

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'indie_scripts' );



	
	

/**
 * Include files
 */

//Custom template tags for this theme.
require get_template_directory() . '/inc/template-tags.php';

// Custom functions that act independently of the theme templates.
require get_template_directory() . '/inc/extras.php';

// Masonry
include get_template_directory() . '/inc/masonry.php';

// Theme Options
include('functions/customizer_controller.php');
include('functions/customizer_settings.php');
include('functions/customizer_styles.php');


/**
 * Exclude Featured Category
 */
function indie_category($separator) {
	
	if(get_theme_mod( 'indie_featured_cat_hide' ) == true) {
		
		$excluded_cat = get_theme_mod('indie_featured_cat');
		
		$first_time = 1;
		foreach((get_the_category()) as $category) {
			if ($category->cat_ID != $excluded_cat) {
				if ($first_time == 1) {
					echo '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "indie" ), $category->name ) . '" ' . '>'  . $category->name.'</a>';
					$first_time = 0;
				} else {
					echo $separator . '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "indie" ), $category->name ) . '" ' . '>' . $category->name.'</a>';
				}
			}
		}
	
	} else {
		
		$first_time = 1;
		foreach((get_the_category()) as $category) {
			if ($first_time == 1) {
				echo '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "indie" ), $category->name ) . '" ' . '>'  . $category->name.'</a>';
				$first_time = 0;
			} else {
				echo $separator . '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "indie" ), $category->name ) . '" ' . '>' . $category->name.'</a>';
			}
		}
	
	}
}

/**
 * Implement the Custom Header feature
 */
require( get_template_directory() . '/inc/custom-header.php' );


/**
 * The Excerpt
 */
function custom_excerpt_length( $length ) {
	return 19;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

function new_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'new_excerpt_more' );



/**
 * Suggested Plugins
 */
require_once get_template_directory() . '/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'indie_register_required_plugins' );

function indie_register_required_plugins() {

    /**
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(

       array(
            'name'               => 'Vafpress Post Formats UI', // The plugin name.
            'slug'               => 'vp-post-formats-ui', // The plugin slug (typically the folder name).
            'source'             => get_stylesheet_directory() . '/plugins/vafpress-post-formats-ui-develop.zip', // The plugin source.
            'required'           => false, // If false, the plugin is only 'recommended' instead of required.
            'version'            => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
            'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url'       => '', // If set, overrides default API URL and points to an external URL.
        ),

    );

    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => __( 'Install Required Plugins', 'tgmpa' ),
            'menu_title'                      => __( 'Install Plugins', 'tgmpa' ),
            'installing'                      => __( 'Installing Plugin: %s', 'tgmpa' ), // %s = plugin name.
            'oops'                            => __( 'Something went wrong with the plugin API.', 'tgmpa' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins' ),
            'return'                          => __( 'Return to Required Plugins Installer', 'tgmpa' ),
            'plugin_activated'                => __( 'Plugin activated successfully.', 'tgmpa' ),
            'complete'                        => __( 'All plugins installed and activated successfully. %s', 'tgmpa' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );

    tgmpa( $plugins, $config );

}

